cosmpy.protos.cosmos.evidence.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.evidence.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.evidence.v1beta1.evidence_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.evidence.v1beta1.evidence_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.evidence.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.evidence.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.evidence.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.evidence.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.evidence.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query defines the gRPC querier service.

  static AllEvidence(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Evidence(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.evidence.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query defines the gRPC querier service.

  AllEvidence(request, context)

    AllEvidence queries all evidence.

  Evidence(request, context)

    Evidence queries evidence based on evidence hash.

class cosmpy.protos.cosmos.evidence.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query defines the gRPC querier service.

cosmpy.protos.cosmos.evidence.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.cosmos.evidence.v1beta1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.evidence.v1beta1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.evidence.v1beta1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the evidence Msg service.

  static SubmitEvidence(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.evidence.v1beta1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the evidence Msg service.

  SubmitEvidence(request, context)

    SubmitEvidence submits an arbitrary Evidence of misbehavior such as equivocation or counterfactual signing.

class cosmpy.protos.cosmos.evidence.v1beta1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the evidence Msg service.

cosmpy.protos.cosmos.evidence.v1beta1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents